@@ -189,50 +189,3 @@ seahorse_pgp_backend_actions_instance (void)
 
     return actions;
 }
-
-GType   seahorse_gpgme_key_actions_get_type       (void) G_GNUC_CONST;
-#define SEAHORSE_TYPE_GPGME_KEY_ACTIONS           (seahorse_gpgme_key_actions_get_type ())
-#define seahorse_gpgme_key_actions(obj)           (G_TYPE_CHECK_INSTANCE_CAST ((obj), SEAHORSE_PGP_TYPE_ACTIONS, SeahorseGpgmeKeyActions))
-#define seahorse_gpgme_key_actions_CLASS(klass)   (G_TYPE_CHECK_CLASS_CAST ((klass), SEAHORSE_PGP_TYPE_ACTIONS, SeahorseGpgmeKeyActionsClass))
-#define SEAHORSE_PGP_IS_ACTIONS(obj)              (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SEAHORSE_PGP_TYPE_ACTIONS))
-#define SEAHORSE_PGP_IS_ACTIONS_CLASS(klass)      (G_TYPE_CHECK_CLASS_TYPE ((klass), SEAHORSE_PGP_TYPE_ACTIONS))
-#define seahorse_gpgme_key_actions_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SEAHORSE_PGP_TYPE_ACTIONS, SeahorseGpgmeKeyActionsClass))
-
-typedef struct {
-    SeahorseActionGroup parent_instance;
-} SeahorseGpgmeKeyActions;
-
-typedef struct {
-    SeahorseActionGroupClass parent_class;
-} SeahorseGpgmeKeyActionsClass;
-
-G_DEFINE_TYPE (SeahorseGpgmeKeyActions, seahorse_gpgme_key_actions, SEAHORSE_TYPE_ACTION_GROUP);
-
-static void
-seahorse_gpgme_key_actions_init (SeahorseGpgmeKeyActions *self)
-{
-}
-
-static void
-seahorse_gpgme_key_actions_class_init (SeahorseGpgmeKeyActionsClass *klass)
-{
-
-}
-
-SeahorseActionGroup *
-seahorse_gpgme_key_actions_instance (void)
-{
-    static SeahorseActionGroup *actions = NULL;
-
-    if (actions == NULL) {
-        actions = g_object_new (SEAHORSE_TYPE_GPGME_KEY_ACTIONS,
-                                "prefix", "gpgme",
-                                NULL);
-        g_object_add_weak_pointer (G_OBJECT (actions),
-                                   (gpointer *)&actions);
-    } else {
-        g_object_ref (actions);
-    }
-
-    return actions;
-}
